package sun.util.locale;

import java.util.Iterator;
import java.util.SortedMap;
import java.util.SortedSet;
import java.util.Collections;
import java.util.Map;
import java.util.Set;

public class UnicodeLocaleExtension extends Extension
{
    public static final char SINGLETON = 'u';
    private final Set<String> attributes;
    private final Map<String, String> keywords;
    public static final UnicodeLocaleExtension CA_JAPANESE;
    public static final UnicodeLocaleExtension NU_THAI;
    
    private UnicodeLocaleExtension(String s, String s2) {
        super('u', s + "-" + s2);
        this.attributes = Collections.emptySet();
        this.keywords = Collections.singletonMap(s, s2);
    }
    
    UnicodeLocaleExtension(SortedSet<String> attributes, SortedMap<String, String> keywords) {
        super('u');
        if (attributes != null) {
            this.attributes = attributes;
        }
        else {
            this.attributes = Collections.emptySet();
        }
        if (keywords != null) {
            this.keywords = keywords;
        }
        else {
            this.keywords = Collections.emptyMap();
        }
        if (!this.attributes.isEmpty() || !this.keywords.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            Iterator<String> iterator = this.attributes.iterator();
            while (iterator.hasNext()) {
                sb.append("-").append((String)iterator.next());
            }
            for (Map.Entry entry : this.keywords.entrySet()) {
                String str = (String)entry.getKey();
                String str2 = (String)entry.getValue();
                sb.append("-").append(str);
                if (str2.length() > 0) {
                    sb.append("-").append(str2);
                }
                else {
                    continue;
                }
            }
            this.setValue(sb.substring(1));
        }
    }
    
    public Set<String> getUnicodeLocaleAttributes() {
        if (this.attributes == Collections.EMPTY_SET) {
            return this.attributes;
        }
        return Collections.unmodifiableSet(this.attributes);
    }
    
    public Set<String> getUnicodeLocaleKeys() {
        if (this.keywords == Collections.EMPTY_MAP) {
            return Collections.emptySet();
        }
        return Collections.unmodifiableSet(this.keywords.keySet());
    }
    
    public String getUnicodeLocaleType(String s) {
        return (String)this.keywords.get(s);
    }
    
    public static boolean isSingletonChar(char c) {
        return 'u' == LocaleUtils.toLower(c);
    }
    
    public static boolean isAttribute(String s) {
        int length = s.length();
        return length >= 3 && length <= 8 && LocaleUtils.isAlphaNumericString(s);
    }
    
    public static boolean isKey(String s) {
        return s.length() == 2 && LocaleUtils.isAlphaNumericString(s);
    }
    
    public static boolean isTypeSubtag(String s) {
        int length = s.length();
        return length >= 3 && length <= 8 && LocaleUtils.isAlphaNumericString(s);
    }
    
    static {
        CA_JAPANESE = new UnicodeLocaleExtension("ca", "japanese");
        NU_THAI = new UnicodeLocaleExtension("nu", "thai");
    }
}
